PathError

Struct PathError 

pub struct PathError {
    pub offset: usize,
    pub kind: PathErrorKind,
}
Why a [path] d string could not be parsed.

Always carries the byte offset into d at which the problem was found — see this module’s header for why that is not optional.

Fields

offset: usize

Byte offset into the d string at which the problem was found.

kind: PathErrorKind

What was wrong there.